% --------------------------------------------------------------------------
% - the CHEMMACROS bundle
% - ghsystem_italian.def
% - loads of little helpers for chemists
% --------------------------------------------------------------------------
% - Clemens Niederberger
% --------------------------------------------------------------------------
% - https://bitbucket.org/cgnieder/chemmacros/
% - contact@mychemistry.eu
% --------------------------------------------------------------------------
% - If you have any ideas, questions, suggestions or bugs to report, please
% - feel free to contact me.
% --------------------------------------------------------------------------
% - Copyright 2011--2020 Clemens Niederberger
% -
% - This work may be distributed and/or modified under the
% - conditions of the LaTeX Project Public License, either version 1.3
% - of this license or (at your option) any later version.
% - The latest version of this license is in
% -   http://www.latex-project.org/lppl.txt
% - and version 1.3 or later is part of all distributions of LaTeX
% - version 2005/12/01 or later.
% -
% - This work has the LPPL maintenance status `maintained'.
% -
% - The Current Maintainer of this work is Clemens Niederberger.
% --------------------------------------------------------------------------
% - the Italian translation was kindly provided by Jonas Rivetti. Many thanks!

% ITALIAN DEFINITIONS
\ghsystemlanguagefile {italian} {2020/02/17}

% table head and foot:
\tl_set:Nn \l_ghsystem_identifier_tl { Numero }
\tl_set:Nn \l_ghsystem_table_text_tl { Frase }
\tl_set:Nn \l_ghsystem_table_next_page_tl { Continua~ nella~ prossima~ pagina }
\tl_set:Nn \l_ghsystem_table_caption_tl
  { Elenco~ di~ tutte~ le~ frasi~ H,~ EUH~ e~ P. }

% fill-in functions:
% <state route of exposure if it is conclusively proven that no other routes of exposure cause the hazard>.
\cs_set:Npn \ghsystem_exposure:
  {
    \bool_if:NT \l_ghsystem_fill_in_bool
      {
        \c_space_tl
        \ghsystem_filler:n
          {
            indicare~ la~ via~ di~ esposizione~ se~ \`e~ accertato~ che~
            nessun'altra~ via~ di~ esposizione~ comporta~ il~ medesimo~ 
            pericolo
          }
      }
  }

%  <state specific effect if known> 
\cs_set:Npn \ghsystem_effect:
  {
    \bool_if:NT \l_ghsystem_fill_in_bool
      {
        \c_space_tl
        \ghsystem_filler:n { indicare~ l'effetto~ specifico,~ se~ noto }
      }
  }

% <or state all organs affected, if known>
\cs_set:Npn \ghsystem_organs:
  {
    \bool_lazy_and:nnT
      { \l_ghsystem_fill_in_bool }
      { !\l_ghsystem_organs_bool }
      {
        \c_space_tl
        \ghsystem_filler:n
          { o~ indicare~ tutti~ gli~ organi~ interessati,~ se~ noti }
      }
  }

\cs_set:Npn \ghsystem_substance:
  {
    \bool_if:NF \l_ghsystem_substance_bool
      {
        \c_space_tl
        \ghsystem_filler:n { denominazione~ della~ sostanza~ sensibilizzante }
      }
  }

% INDICAZIONI DI PERICOLO (Allegato 3)
% 1. Indicazioni di pericolo
% 1.1 Pericoli fisici
\ghsystem_add_statement:nnn {H} { 200 }
  { Esplosivo~ instabile. }
\ghsystem_add_statement:nnn {H} { 201 }
  { Esplosivo;~ pericolo~ di~ esplosione~ di~ massa. }
\ghsystem_add_statement:nnn {H} { 202 }
  { Esplosivo;~ grave~ pericolo~ di~ proiezione. }
\ghsystem_add_statement:nnn {H} { 203 }
  {
    Esplosivo;~ pericolo~ di~ incendio,~ di~ spostamento~ d'aria~ o~ di~
    proiezione.
  }
\ghsystem_add_statement:nnn {H} { 204 }
  { Pericolo~ di~ incendio~ o~ di~ proiezione. }
\ghsystem_add_statement:nnn {H} { 205 }
  { Pericolo~ di~ esplosione~ di~ massa~ in~ caso~ d'incendio. }
\ghsystem_add_statement:nnn {H} { 220 }
  { Gas~ altamente~ infiammabile. }
\ghsystem_add_statement:nnn {H} { 221 }
  { Gas~ infiammabile. }
\ghsystem_add_statement:nnn {H} { 222 }
  { Aerosol~ altamente~ infiammabile. }
\ghsystem_add_statement:nnn {H} { 223 }
  { Aerosol~ infiammabile. }
\ghsystem_add_statement:nnn {H} { 224 }
  { Liquido~ e~ vapori~ altamente~ infiammabili. }
\ghsystem_add_statement:nnn {H} { 225 }
  { Liquido~ e~ vapori~ facilmente~ infiammabili. }
\ghsystem_add_statement:nnn {H} { 226 }
  { Liquido~ e~ vapori~ infiammabili. }
\ghsystem_add_statement:nnn {H} { 228 }
  { Solido~ infiammabile. }
\ghsystem_add_statement:nnn {H} { 240 }
  { Rischio~ di~ esplosione~ per~ riscaldamento. }
\ghsystem_add_statement:nnn {H} { 241 }
  { Rischio~ d'incendio~ o~ di~ esplosione~ per~ riscaldamento. }
\ghsystem_add_statement:nnn {H} { 242 }
  { Rischio~ d'incendio~ per~ riscaldamento. }
\ghsystem_add_statement:nnn {H} { 250 }
  { Spontaneamente~ infiammabile~ all'aria. }
\ghsystem_add_statement:nnn {H} { 251 }
  { Autoriscaldante;~ pu\`o~ infiammarsi. }
\ghsystem_add_statement:nnn {H} { 252 }
  { Autoriscaldante~ in~ grandi~ quantit\`a;~ pu\`o~ infiammarsi. }
\ghsystem_add_statement:nnn {H} { 260 }
  {
    A~ contatto~ con~ l'acqua~ libera~ gas~ infiammabili~ che~ possono~
    infiammarsi~ spontaneamente.
  }
\ghsystem_add_statement:nnn {H} { 261 }
  { A~ contatto~ con~ l'acqua~ libera~ gas~ infiammabili. }
\ghsystem_add_statement:nnn {H} { 270 }
  { Pu\`o~ provocare~ o~ aggravare~ un~ incendio;~ comburente. }
\ghsystem_add_statement:nnn {H} { 271 }
  { Pu\`o~ provocare~ un~ incendio~ o~ un'esplosione;~ molto~ comburente. }
\ghsystem_add_statement:nnn {H} { 272 }
  { Pu\`o~ aggravare~ un~ incendio;~ comburente. }
\ghsystem_add_statement:nnn {H} { 280 }
  { Contiene~ gas~ sotto~ pressione;~ pu\`o~ esplodere~ se~ riscaldato. }
\ghsystem_add_statement:nnn {H} { 281 }
  {
    Contiene~ gas~ refrigerato;~ pu\`o~ provocare~ ustioni~ o~ lesioni~
    criogeniche.
  }
\ghsystem_add_statement:nnn {H} { 290 }
  { Pu\`o~ essere~ corrosivo~ per~ i~ metalli. }

% 1.2 Pericoli per la salute
\ghsystem_add_statement:nnn {H} { 300 }
  { Letale~ se~ ingerito. }
\ghsystem_add_statement:nnn {H} { 301 }
  { Tossico~ se~ ingerito. }
\ghsystem_add_statement:nnn {H} { 302 }
  { Nocivo~ se~ ingerito. }
\ghsystem_add_statement:nnn {H} { 304 }
  {
    Pu\`o~ essere~ letale~ in~ caso~ di~ ingestione~ e~ di~ penetrazione~
    nelle~ vie~ respiratorie.
  }
\ghsystem_add_statement:nnn {H} { 310 }
  { Letale~ per~ contatto~ con~ la~ pelle. }
\ghsystem_add_statement:nnn {H} { 311 }
  { Tossico~ per~ contatto~ con~ la~ pelle. }
\ghsystem_add_statement:nnn {H} { 312 }
  { Nocivo~ per~ contatto~ con~ la~ pelle. }
\ghsystem_add_statement:nnn {H} { 314 }
  { Provoca~ gravi~ ustioni~ cutanee~ e~ gravi~ lesioni~ oculari. }
\ghsystem_add_statement:nnn {H} { 315 }
  { Provoca~ irritazione~ cutanea. }
\ghsystem_add_statement:nnn {H} { 317 }
  { Pu\`o~ provocare~ una~ reazione~ allergica~ cutanea. }
\ghsystem_add_statement:nnn {H} { 318 }
  { Provoca~ gravi~ lesioni~ oculari. }
\ghsystem_add_statement:nnn {H} { 319 }
  { Provoca~ grave~ irritazione~ oculare. }
\ghsystem_add_statement:nnn {H} { 330 }
  { Letale~ se~ inalato. }
\ghsystem_add_statement:nnn {H} { 331 }
  { Tossico~ se~ inalato. }
\ghsystem_add_statement:nnn {H} { 332 }
  { Nocivo~ se~ inalato. }
\ghsystem_add_statement:nnn {H} { 334 }
  {
    Pu\`o~ provocare~ sintomi~ allergici~ o~ asmatici~ o~ difficolt\`a~
    respiratorie~ se~ inalato.
  }
\ghsystem_add_statement:nnn {H} { 335 }
  { Pu\`o~ irritare~ le~ vie~ respiratorie. }
\ghsystem_add_statement:nnn {H} { 336 }
  { Pu\`o~ provocare~ sonnolenza~ o~ vertigini. }
\ghsystem_add_statement:nnn {H} { 340 }
  { Pu\`o~ provocare~ alterazioni~ genetiche. \ghsystem_exposure: }
\ghsystem_add_statement:nnn {H} { 341 }
  { Sospettato~ di~ provocare~ alterazioni~ genetiche. \ghsystem_exposure: }
\ghsystem_add_statement:nnn {H} { 350 }
  { Pu\`o~ provocare~ il~ cancro. \ghsystem_exposure: }
\ghsystem_add_statement:nnn {H} { 351 }
  { Sospettato~ di~ provocare~ il~ cancro. \ghsystem_exposure: }
\ghsystem_add_statement:nnn {H} { 360 }
  {
    Pu\`o~ nuocere~ alla~ fertilit\`a~ o~ al~ feto. \ghsystem_effect:
    \ghsystem_exposure:
  }
\ghsystem_add_statement:nnn {H} { 361 }
  {
    Sospettato~ di~ nuocere~ alla~ fertilit\`a~ o~ al~ feto \ghsystem_effect:
    \ghsystem_exposure:
  }
\ghsystem_add_statement:nnn {H} { 362 }
  { Pu\`o~ essere~ nocivo~ per~ i~ lattanti~ allattati~ al~ seno. }
\ghsystem_add_statement:nnn {H} { 370 }
  {
    Provoca~ danni \bool_if:NF \l_ghsystem_organs_bool { ~ agli~ organi }
    \ghsystem_organs: . \ghsystem_exposure:
  }
\ghsystem_add_statement:nnn {H} { 371 }
  {
    Pu\`o~ provocare~ danni \bool_if:NF \l_ghsystem_organs_bool { ~ agli~
      organi } \ghsystem_organs: . \ghsystem_exposure:
  }
\ghsystem_add_statement:nnn {H} { 372 }
  {
    Provoca~ danni \bool_if:NF \l_ghsystem_organs_bool { ~ agli~ organi }
    \ghsystem_organs:\ in~ caso~ di~ esposizione~ prolungata~ o~ ripetuta.
    \ghsystem_exposure:
  }
  
\ghsystem_add_statement:nnn {H} { 373 }
  {
    Pu\`o~ provocare~ danni \bool_if:NF \l_ghsystem_organs_bool { ~ agli~
      organi } \ghsystem_organs:\ in~ caso~ di~ esposizione~ prolungata~ o~
    ripetuta.  \ghsystem_exposure: 
  }

% 1.3 Pericoli per l'ambiente
\ghsystem_add_statement:nnn {H} { 400 }
  { Molto~ tossico~ per~ gli~ organismi~ acquatici. }
\ghsystem_add_statement:nnn {H} { 410 }
  {
    Molto~ tossico~ per~ gli~ organismi~ acquatici~ con~ effetti~ di~ lunga~
    durata.
  }
\ghsystem_add_statement:nnn {H} { 411 }
  { Tossico~ per~ gli~ organismi~ acquatici~ con~ effetti~ di~ lunga~ durata. }
\ghsystem_add_statement:nnn {H} { 412 }
  { Nocivo~ per~ gli~ organismi~ acquatici~ con~ effetti~ di~ lunga~ durata. }
\ghsystem_add_statement:nnn {H} { 413 }
  {
    Pu\`o~ essere~ nocivo~ per~ gli~ organismi~ acquatici~ con~ effetti~ di~
    lunga~ durata.
  }

% 2 Informazioni supplementari sui pericoli
% 2.1 Proprieta` fisiche
\ghsystem_add_statement:nnn {EUH} { 001 }
  { Esplosivo~ allo~ stato~ secco. }
\ghsystem_add_statement:nnn {EUH} { 006 }
  { Esplosivo~ a~ contatto~ o~ senza~ contatto~ con~ l'aria. }
\ghsystem_add_statement:nnn {EUH} { 014 }
  { Reagisce~ violentemente~ con~ l'acqua. }
\ghsystem_add_statement:nnn {EUH} { 018 }
  {
    Durante~ l'uso~ pu\`o~ formarsi~ una~ miscela~ vapore-aria~
    esplosiva\ghsystem_slash: infiammabile.
  }
\ghsystem_add_statement:nnn {EUH} { 019 }
  { Pu\`o~ formare~ perossidi~ esplosivi. }
\ghsystem_add_statement:nnn {EUH} { 044 }
  { Rischio~ di~ esplosione~ per~ riscaldamento~ in~ ambiente~ confinato. }

% 2.2 Proprieta` pericolose per la salute
\ghsystem_add_statement:nnn {EUH} { 029 }
  { A~ contatto~ con~ l'acqua~ libera~ un~ gas~ tossico. }
\ghsystem_add_statement:nnn {EUH} { 031 }
  { A~ contatto~ con~ acidi~ libera~ gas~ tossici. }
\ghsystem_add_statement:nnn {EUH} { 032 }
  { A~ contatto~ con~ acidi~ libera~ gas~ molto~ tossici. }
\ghsystem_add_statement:nnn {EUH} { 066 }
  {
    L'esposizione~ ripetuta~ pu\`o~ provocare~ secchezza~ o~ screpolature~
    della~ pelle.
  }
\ghsystem_add_statement:nnn {EUH} { 070 }
  { Tossico~ per~ contatto~ oculare. }
\ghsystem_add_statement:nnn {EUH} { 071 }
  { Corrosivo~ per~ le~ vie~ respiratorie. }

% 2.3 Proprieta` pericolose per l'ambiente
\ghsystem_add_statement:nnn {EUH} { 059 }
  { Pericoloso~ per~ lo~ strato~ di~ ozono. }

% 2.4 Elementi descrittivi aggiuntivi / Informazioni riguardanti particolari sostanze e miscele
\ghsystem_add_statement:nnn {EUH} { 201 }
  {
    Contiene~ piombo.~ Non~ utilizzare~ su~ oggetti~ che~ possono~ essere~
    masticati~ o~ succhiati~ dai~ bambini.
  }
\ghsystem_add_statement:nnn {EUH} { 201A }
  { Attenzione!~ Contiene~ piombo. }
\ghsystem_add_statement:nnn {EUH} { 202 }
  {
    Cianoacrilato.~ Pericolo.~ Incolla~ la~ pelle~ e~ gli~ occhi~ in~ pochi~
    secondi.~ Tenere~ fuori~ dalla~ portata~ dei~ bambini.
  }
\ghsystem_add_statement:nnn {EUH} { 203 }
  { Contiene~ cromo\,(VI).~ Pu\`o~ provocare~ una~ reazione~ allergica. }
\ghsystem_add_statement:nnn {EUH} { 204 }
  { Contiene~ isocianati.~ Pu\`o~ provocare~ una~ reazione~ allergica. }
\ghsystem_add_statement:nnn {EUH} { 205 }
  {
    Contiene~ componenti~ epossidici.~ Pu\`o~ provocare~ una~ reazione~
    allergica.
  }
\ghsystem_add_statement:nnn {EUH} { 206 }
  {
    Attenzione!~ Non~ utilizzare~ in~ combinazione~ con~ altri~ prodotti.~
    Possono~ liberarsi~ gas~ pericolosi~ (cloro).
  }
\ghsystem_add_statement:nnn {EUH} { 207 }
  {
    Attenzione!~ Contiene~ cadmio.~ Durante~ l'uso~ si~ sviluppano~ fumi~
    pericolosi.~ Leggere~ le~ informazioni~ fornite~ dal~ fabbricante.~
    Rispettare~ le~ disposizioni~ di~ sicurezza.
  }
\ghsystem_add_statement:nnn {EUH} { 208 }
  {
    Contiene \ghsystem_substance: .~ Pu\`o~ provocare~ una~ reazione~
    allergica.
  }
\ghsystem_add_statement:nnn {EUH} { 209 }
  { Pu\`o~ diventare~ facilmente~ infiammabile~ durante~ l'uso. }
\ghsystem_add_statement:nnn {EUH} { 209A }
  { Pu\`o~ diventare~ infiammabile~ durante~ l'uso. }
\ghsystem_add_statement:nnn {EUH} { 210 }
  { Scheda~ dati~ di~ sicurezza~ disponibile~ su~ richiesta. }
\ghsystem_add_statement:nnn {EUH} { 401 }
  {
    Per~ evitare~ rischi~ per~ la~ salute~ umana~ e~ per~ l'ambiente,~
    seguire~ le~ istruzioni~ per~ l'uso.
  }

% CONSIGLI DI PRUDENZA (Allegato 4, da pagina 19)
% 3 Consigli di prudenza
% 3.1 Consigli di prudenza di carattere generale
\ghsystem_add_statement:nnn {P} { 101 }
  {
    In~ caso~ di~ consultazione~ di~ un~ medico,~ tenere~ a~ disposizione~ il~
    contenitore~ o~ l'etichetta~ del~ prodotto.
  }
\ghsystem_add_statement:nnn {P} { 102 }
  { Tenere~ fuori~ dalla~ portata~ dei~ bambini. }
\ghsystem_add_statement:nnn {P} { 103 }
  { Leggere~ l'etichetta~ prima~ dell'uso. }

% 3.2 Consigli di prudenza - Prevenzione
\ghsystem_add_statement:nnn {P} { 201 }
  { Procurarsi~ istruzioni~ specifiche~ prima~ dell'uso. }
\ghsystem_add_statement:nnn {P} { 202 }
  {
    Non~ manipolare~ prima~ di~ avere~ letto~ e~ compreso~ tutte~ le~
    avvertenze.
  }
\ghsystem_add_statement:nnn {P} { 210 }
  {
    Tenere~ lontano~ da~ fonti~ di~ calore\ghsystem_slash:
    scintille\ghsystem_slash: fiamme~ libere\ghsystem_slash: superfici~
    riscaldate.~  \textemdash ~ Non~ fumare.
  }
\ghsystem_add_statement:nnn {P} { 211 }
  {
    Non~ vaporizzare~ su~ una~ fiamma~ libera~ o~ altra~ fonte~ di~
    accensione.
  }
\ghsystem_add_statement:nnn {P} { 220 }
  {
    Tenere\ghsystem_slash: conservare~ lontano~ da~ indumenti\ghsystem_slash:
    \l_ghsystem_dots_tl \ghsystem_slash: materiali~ combustibili.
  }
\ghsystem_add_statement:nnn {P} { 221 }
  {
    Prendere~ ogni~ precauzione~ per~ evitare~ di~ miscelare~ con~ sostanze~
    combustibili~ \l_ghsystem_dots_tl .
  }
\ghsystem_add_statement:nnn {P} { 222 }
  { Evitare~ il~ contatto~ con~ l'aria. }
\ghsystem_add_statement:nnn {P} { 223 }
  {
    Evitare~ qualsiasi~ contatto~ con~ l'acqua:~ pericolo~ di~ reazione~
    violenta~ e~ di~ infiammazione~ spontanea.
  }
\ghsystem_add_statement:nnn {P} { 230 }
  { Mantenere~ umido~ con~ \l_ghsystem_dots_tl . }
\ghsystem_add_statement:nnn {P} { 231 }
  { Manipolare~ in~ atmosfera~ di~ gas~ inerte. }
\ghsystem_add_statement:nnn {P} { 232 }
  { Proteggere~ dall'umidit\`a. }
\ghsystem_add_statement:nnn {P} { 233 }
  { Tenere~ il~ recipiente~ ben~ chiuso. }
\ghsystem_add_statement:nnn {P} { 234 }
  { Conservare~ soltanto~ nel~ contenitore~ originale. }
\ghsystem_add_statement:nnn {P} { 235 }
  { Conservare~ in~ luogo~ fresco. }
\ghsystem_add_statement:nnn {P} { 240 }
  {
    Mettere~ a~ terra\ghsystem_slash: massa~ il~ contenitore~ e~ il~
    dispositivo~ ricevente.
  }
\ghsystem_add_statement:nnn {P} { 241 }
  {
    Utilizzare~ impianti~ elettrici\ghsystem_slash: di~
    ventilazione\ghsystem_slash: d'illuminazione\ghsystem_slash:
    \l_ghsystem_dots_tl \ghsystem_slash: a~ prova~ di~ esplosione.
  }
\ghsystem_add_statement:nnn {P} { 242 }
  { Utilizzare~ solo~ utensili~ antiscintillamento. }
\ghsystem_add_statement:nnn {P} { 243 }
  { Prendere~ precauzioni~ contro~ le~ scariche~ elettrostatiche. }
\ghsystem_add_statement:nnn {P} { 244 }
  { Mantenere~ le~ valvole~ di~ riduzione~ libere~ da~ grasso~ e~ olio. }
\ghsystem_add_statement:nnn {P} { 250 }
  {
    Evitare~ le~ abrasioni\ghsystem_slash: gli~ urti\ghsystem_slash:
    \l_ghsystem_dots_tl \ghsystem_slash: gli~ attriti.
  }
\ghsystem_add_statement:nnn {P} { 251 }
  {
    Recipiente~ sotto~ pressione:~ non~ perforare~ n\'e~ bruciare,~ neppure~
    dopo~ l'uso.
  }
\ghsystem_add_statement:nnn {P} { 260 }
  {
    Non~ respirare~ la~ polvere\ghsystem_slash: i~ fumi\ghsystem_slash: i~
    gas\ghsystem_slash: la~ nebbia\ghsystem_slash: i~ vapori\ghsystem_slash:
    gli~ aerosol.
  }
\ghsystem_add_statement:nnn {P} { 261 }
  {
    Evitare~ di~ respirare~ la~ polvere\ghsystem_slash: i~
    fumi\ghsystem_slash: i~ gas\ghsystem_slash: la~ nebbia\ghsystem_slash: i~
    vapori\ghsystem_slash: gli~ aerosol.
  }
\ghsystem_add_statement:nnn {P} { 262 }
  { Evitare~ il~ contatto~ con~ gli~ occhi,~ la~ pelle~ o~ gli~ indumenti. }
\ghsystem_add_statement:nnn {P} { 263 }
  { Evitare~ il~ contatto~ durante~ la~ gravidanza\ghsystem_slash: l'allattamento. }
\ghsystem_add_statement:nnn {P} { 264 }
  { Lavare~ accuratamente~ \l_ghsystem_dots_tl\ dopo~ l'uso. }
\ghsystem_add_statement:nnn {P} { 270 }
  { Non~ mangiare,~ n\'e~ bere,~ n\'e~ fumare~ durante~ l'uso. }
\ghsystem_add_statement:nnn {P} { 271 }
  { Utilizzare~ soltanto~ all'aperto~ o~ in~ luogo~ ben~ ventilato. }
\ghsystem_add_statement:nnn {P} { 272 }
  {
    Gli~ indumenti~ da~ lavoro~ contaminati~ non~ devono~ essere~ portati~
    fuori~ dal~ luogo~ di~ lavoro.
  }
\ghsystem_add_statement:nnn {P} { 273 }
  { Non~ disperdere~ nell'ambiente. }
\ghsystem_add_statement:nnn {P} { 280 }
  {
    Indossare~ guanti\ghsystem_slash: indumenti~ protettivi\ghsystem_slash:
    Proteggere~ gli~ occhi\ghsystem_slash: il~ viso.
  }
\ghsystem_add_statement:nnn {P} { 281 }
  { Utilizzare~ il~ dispositivo~ di~ protezione~ individuale~ richiesto. }
\ghsystem_add_statement:nnn {P} { 282 }
  {
    Utilizzare~ guanti~ termici\ghsystem_slash: schermo~
    facciale\ghsystem_slash: Proteggere~ gli~ occhi.
  }
\ghsystem_add_statement:nnn {P} { 283 }
  {
    Indossare~ indumenti~ completamente~ ignifughi~ o~ in~ tessuti~
    ritardanti~ di~ fiamma.
  }
\ghsystem_add_statement:nnn {P} { 284 }
  { Utilizzare~ un~ apparecchio~ respiratorio. }
\ghsystem_add_statement:nnn {P} { 285 }
  {
    In~ caso~ di~ ventilazione~ insufficiente~ utilizzare~ un~ apparecchio~
    respiratorio.
  }
\ghsystem_add_statement:nnn {P} { 231 + 232 }
  {
    Manipolare~ in~ atmosfera~ di~ gas~ inerte.~ Tenere~ al~ riparo~
    dall'umidit\`a.
  }
\ghsystem_add_statement:nnn {P} { 235 + 410 }
  { Tenere~ in~ luogo~ fresco.~ Proteggere~ dai~ raggi~ solari. }

% 3.3 Consigli di prudenza - Reazione
\ghsystem_add_statement:nnn {P} { 301 }
  { IN~ CASO~ DI~ INGESTIONE: \ghsystem_text: }
\ghsystem_add_statement:nnn {P} { 302 }
  { IN~ CASO~ DI~ CONTATTO~ CON~ LA~ PELLE: \ghsystem_text: }
\ghsystem_add_statement:nnn {P} { 303 }
  { IN~ CASO~ DI~ CONTATTO~ CON~ LA~ PELLE~ (o~ con~ i~ capelli): \ghsystem_text: }
\ghsystem_add_statement:nnn {P} { 304 }
  { IN~ CASO~ DI~ INALAZIONE: \ghsystem_text: }
\ghsystem_add_statement:nnn {P} { 305 }
  { IN~ CASO~ DI~ CONTATTO~ CON~ GLI~ OCCHI: \ghsystem_text: }
\ghsystem_add_statement:nnn {P} { 306 }
  { IN~ CASO~ DI~ CONTATTO~ CON~ GLI~ INDUMENTI: \ghsystem_text: }
\ghsystem_add_statement:nnn {P} { 307 }
  { IN~ CASO~ di~ esposizione: \ghsystem_text: }
\ghsystem_add_statement:nnn {P} { 308 }
  { IN~ CASO~ di~ esposizione~ o~ di~ possibile~ esposizione: \ghsystem_text: }
\ghsystem_add_statement:nnn {P} { 309 }
  { IN~ CASO~ di~ esposizione~ o~ di~ malessere: \ghsystem_text: }
\ghsystem_add_statement:nnn {P} { 310 }
  { Contattare~ immediatamente~ un~ CENTRO~ ANTIVELENI~ o~ un~ medico. }
\ghsystem_add_statement:nnn {P} { 311 }
  { Contattare~ un~ CENTRO~ ANTIVELENI~ o~ un~ medico. }
\ghsystem_add_statement:nnn {P} { 312 }
  {
    In~ caso~ di~ malessere,~ contattare~ un~ CENTRO~ ANTIVELENI~ o~ un~
    medico.
  }
\ghsystem_add_statement:nnn {P} { 313 }
  { Consultare~ un~ medico. }
\ghsystem_add_statement:nnn {P} { 314 }
  { In~ caso~ di~ malessere,~ consultare~ un~ medico. }
\ghsystem_add_statement:nnn {P} { 315 }
  { Consultare~ immediatamente~ un~ medico. }
\ghsystem_add_statement:nnn {P} { 320 }
  {
    Trattamento~ specifico~ urgente~ (vedere~ \l_ghsystem_dots_tl\ su~
    questa~ etichetta).
  }
\ghsystem_add_statement:nnn {P} { 321 }
  {
    Trattamento~ specifico~ (vedere~ \l_ghsystem_dots_tl\ su~ questa~
    etichetta).
  }
\ghsystem_add_statement:nnn {P} { 322 }
  {
    Misure~ specifiche~ (vedere~ \l_ghsystem_dots_tl\ su~ questa~
    etichetta).
  }
\ghsystem_add_statement:nnn {P} { 330 }
  { Sciacquare~ la~ bocca. }
\ghsystem_add_statement:nnn {P} { 331 }
  { NON~ provocare~ il~ vomito. }
\ghsystem_add_statement:nnn {P} { 332 }
  { In~ caso~ di~ irritazione~ della~ pelle: \ghsystem_text: }
\ghsystem_add_statement:nnn {P} { 333 }
  { In~ caso~ di~ irritazione~ o~ eruzione~ della~ pelle: \ghsystem_text: }
\ghsystem_add_statement:nnn {P} { 334 }
  {
    Immergere~ in~ acqua~ fredda\ghsystem_slash: avvolgere~ con~ un~
    bendaggio~ umido.
  }
\ghsystem_add_statement:nnn {P} { 335 }
  { Rimuovere~ le~ particelle~ depositate~ sulla~ pelle. }
\ghsystem_add_statement:nnn {P} { 336 }
  {
    Sgelare~ le~ parti~ congelate~ usando~ acqua~ tiepida.~ Non~ sfregare~ la~
    parte~ interessata.
  }
\ghsystem_add_statement:nnn {P} { 337 }
  { Se~ l'irritazione~ degli~ occhi~ persiste: \ghsystem_text: }
\ghsystem_add_statement:nnn {P} { 338 }
  {
    Togliere~ le~ eventuali~ lenti~ a~ contatto~ se~ \`e~ agevole~ farlo.~
    Continuare~ a~ sciacquare.
  }
\ghsystem_add_statement:nnn {P} { 340 }
  {
    Trasportare~ l'infortunato~ all'aria~ aperta~ e~ mantenerlo~ a~ riposo~
    in~ posizione~ che~ favorisca~ la~ respirazione.
  }
\ghsystem_add_statement:nnn {P} { 341 }
  {
    Se~ la~ respirazione~ \`e~ difficile,~ trasportare~ l'infortunato~
    all'aria~ aperta~ e~ mantenerlo~ a~ riposo~ in~ posizione~ che~ favorisca~
    la~ respirazione.
  }
\ghsystem_add_statement:nnn {P} { 342 }
  { In~ caso~ di~ sintomi~ respiratori: \ghsystem_text: }
\ghsystem_add_statement:nnn {P} { 350 }
  { Lavare~ delicatamente~ e~ abbondantemente~ con~ acqua~ e~ sapone. }
\ghsystem_add_statement:nnn {P} { 351 }
  { Sciacquare~ accuratamente~ per~ parecchi~ minuti. }
\ghsystem_add_statement:nnn {P} { 352 }
  { Lavare~ abbondantemente~ con~ acqua~ e~ sapone. }
\ghsystem_add_statement:nnn {P} { 353 }
  { Sciacquare~ la~ pelle\ghsystem_slash: fare~ una~ doccia. }
\ghsystem_add_statement:nnn {P} { 360 }
  {
    Sciacquare~ immediatamente~ e~ abbondantemente~ gli~ indumenti~
    contaminati~ e~ la~ pelle~ prima~ di~ togliersi~ gli~ indumenti.
  }
\ghsystem_add_statement:nnn {P} { 361 }
  { Togliersi~ di~ dosso~ immediatamente~ tutti~ gli~ indumenti~ contaminati. }
\ghsystem_add_statement:nnn {P} { 362 }
  {
    Togliersi~ di~ dosso~ gli~ indumenti~ contaminati~ e~ lavarli~ prima~ di~
    indossarli~ nuovamente.
  }
\ghsystem_add_statement:nnn {P} { 363 }
  { Lavare~ gli~ indumenti~ contaminati~ prima~ di~ indossarli~ nuovamente. }
\ghsystem_add_statement:nnn {P} { 370 }
  { In~ caso~ di~ incendio: \ghsystem_text: }
\ghsystem_add_statement:nnn {P} { 371 }
  { In~ caso~ di~ incendio~ grave~ e~ di~ quantit\`a~ rilevanti: \ghsystem_text: }
\ghsystem_add_statement:nnn {P} { 372 }
  { Rischio~ di~ esplosione~ in~ caso~ di~ incendio. }
\ghsystem_add_statement:nnn {P} { 373 }
  {
    NON~ utilizzare~ mezzi~ estinguenti~ se~ l'incendio~ raggiunge~ materiali~
    esplosivi.
  }
\ghsystem_add_statement:nnn {P} { 374 }
  {
    Utilizzare~ i~ mezzi~ estinguenti~ con~ le~ precauzioni~ abituali~ a~
    distanza~ ragionevole.
  }
\ghsystem_add_statement:nnn {P} { 375 }
  {
    Rischio~ di~ esplosione.~ Utilizzare~ i~ mezzi~ estinguenti~ a~ grande~
    distanza.
  }
\ghsystem_add_statement:nnn {P} { 376 }
  { Bloccare~ la~ perdita~ se~ non~ c'\`e~ pericolo. }
\ghsystem_add_statement:nnn {P} { 377 }
  {
    In~ caso~ d'incendio~ dovuto~ a~ perdita~ di~ gas \ghsystem_text: , ~ non~
    estinguere~ a~ meno~ che~ non~ sia~ possibile~ bloccare~ la~ perdita~
    senza~ pericolo.
  }
\ghsystem_add_statement:nnn {P} { 378 }
  { Estinguere~ con~ \l_ghsystem_dots_tl . }
\ghsystem_add_statement:nnn {P} { 380 }
  { Evacuare~ la~ zona. }
\ghsystem_add_statement:nnn {P} { 381 }
  { Eliminare~ ogni~ fonte~ di~ accensione~ se~ non~ c'\`e~ pericolo. }
\ghsystem_add_statement:nnn {P} { 390 }
  { Assorbire~ la~ fuoriuscita~ per~ evitare~ danni~ materiali. }
\ghsystem_add_statement:nnn {P} { 391 }
  { Raccogliere~ il~ materiale~ fuoriuscito. }
\ghsystem_add_statement:nnn {P} { 301 + 310 }
  {
    IN~ CASO~ DI~ INGESTIONE:~ contattare~ immediatamente~ un~ CENTRO~
    ANTIVELENI~ o~ un~ medico.
  }
\ghsystem_add_statement:nnn {P} { 301 + 312 }
  {
    IN~ CASO~ DI~ INGESTIONE~ accompagnata~ da~ malessere:~ contattare~ un~
    CENTRO ANTIVELENI~ o~ un~ medico.
  }
\ghsystem_add_statement:nnn {P} { 301 + 330 + 331 }
  {
    IN~ CASO~ DI~ INGESTIONE:~ sciacquare~ la~ bocca.~ NON~ provocare~ il~
    vomito.
  }
\ghsystem_add_statement:nnn {P} { 302 + 334 }
  {
    IN~ CASO~ DI~ CONTATTO~ CON~ LA~ PELLE:~ immergere~ in~ acqua~
    fredda\ghsystem_slash: avvolgere~ con~ un~ bendaggio~ umido.
  }
\ghsystem_add_statement:nnn {P} { 302 + 350 }
  {
    IN~ CASO~ DI~ CONTATTO~ CON~ LA~ PELLE:~ lavare~ delicatamente~ e~
    abbondantemente~ con~ acqua~ e~ sapone.
  }
\ghsystem_add_statement:nnn {P} { 302 + 352 }
  {
    IN~ CASO~ DI~ CONTATTO~ CON~ LA~ PELLE:~ lavare~ abbondantemente~ con~
    acqua~ e~ sapone.
  }
\ghsystem_add_statement:nnn {P} { 303 + 361 + 353 }
  {
    IN~ CASO~ DI~ CONTATTO~ CON~ LA~ PELLE~ (o~ con~ i~ capelli):~ togliersi~
    di~ dosso~ immediatamente~ tutti~ gli~ indumenti~ contaminati.~
    Sciacquare~ la~ pelle\ghsystem_slash: fare~ una~ doccia.
  }
\ghsystem_add_statement:nnn {P} { 304 + 340 }
  {
    IN~ CASO~ DI~ INALAZIONE:~ trasportare~ l'infortunato~ all'aria~ aperta~
    e~ mantenerlo~ a~ riposo~ in~ posizione~ che~ favorisca~ la~ respirazione.
  }
\ghsystem_add_statement:nnn {P} { 304 + 341 }
  {
    IN~ CASO~ DI~ INALAZIONE:~ se~ la~ respirazione~ \`e~ difficile,~
    trasportare~ l'infortunato~ all'aria~ aperta~ e~ mantenerlo~ a~ riposo~
    in~ posizione~ che~ favorisca~ la~ respirazione.
  }
\ghsystem_add_statement:nnn {P} { 305 + 351 + 338 }
  {
    IN~ CASO~ DI~ CONTATTO~ CON~ GLI~ OCCHI:~ sciacquare~ accuratamente~ per~
    parecchi~ minuti.~ Togliere~ le~ eventuali~ lenti~ a~ contatto~ se~ \`e~
    agevole~ farlo.~ Continuare~ a~ sciacquare.
  }
\ghsystem_add_statement:nnn {P} { 306 + 360 }
  {
    IN~ CASO~ DI~ CONTATTO~ CON~ GLI~ INDUMENTI:~ sciacquare~ immediatamente~
    e~ abbondantemente~ gli~ indumenti~ contaminati~ e~ la~ pelle~ prima~ di~
    togliersi~ gli~ indumenti.
  }
\ghsystem_add_statement:nnn {P} { 307 + 311 }
  {
    IN~ CASO~ di~ esposizione,~ contattare~ un~ CENTRO~ ANTIVELENI~ o~ un~
    medico.
  }
\ghsystem_add_statement:nnn {P} { 308 + 313 }
  {
    IN~ CASO~ di~ esposizione~ o~ di~ possibile~ esposizione,~ consultare~ un~
    medico.
  }
\ghsystem_add_statement:nnn {P} { 309 + 311 }
  {
    IN~ CASO~ di~ esposizione~ o~ di~ malessere,~ contattare~ un~ CENTRO~
    ANTIVELENI~ o~ un~ medico.
  }
\ghsystem_add_statement:nnn {P} { 332 + 313 }
  { In~ caso~ di~ irritazione~ della~ pelle:~ consultare~ un~ medico. }
\ghsystem_add_statement:nnn {P} { 333 + 313 }
  {
    In~ caso~ di~ irritazione~ o~ eruzione~ della~ pelle:~ consultare~ un~
    medico.
  }
\ghsystem_add_statement:nnn {P} { 335 + 334 }
  {
    Rimuovere~ le~ particelle~ depositate~ sulla~ pelle.~ Immergere~ in~
    acqua~ fredda\ghsystem_slash: avvolgere~ con~ un~ bendaggio~ umido.
  }
\ghsystem_add_statement:nnn {P} { 337 + 313 }
  { Se~ l'irritazione~ degli~ occhi~ persiste,~ consultare~ un~ medico. }
\ghsystem_add_statement:nnn {P} { 342 + 311 }
  {
    In~ caso~ di~ sintomi~ respiratori:~ contattare~ un~ CENTRO~ ANTIVELENI~
    o~ un~ medico.
  }
\ghsystem_add_statement:nnn {P} { 370 + 376 }
  { In~ caso~ di~ incendio:~ bloccare~ la~ perdita~ se~ non~ c'\`e~ pericolo. }
\ghsystem_add_statement:nnn {P} { 370 + 378 }
  { In~ caso~ di~ incendio:~ estinguere~ con~  \l_ghsystem_dots_tl . }
\ghsystem_add_statement:nnn {P} { 370 + 380 }
  { Evacuare~ la~ zona~ in~ caso~ di~ incendio. }
\ghsystem_add_statement:nnn {P} { 370 + 380 + 375 }
  {
    In~ caso~ di~ incendio:~ evacuare~ la~ zona.~ Rischio~ di~ esplosione.~
    Utilizzare~ i~ mezzi~ estinguenti~ a~ grande~ distanza.
  }
\ghsystem_add_statement:nnn {P} { 371 + 380 + 375 }
  {
    In~ caso~ di~ incendio~ grave~ e~ di~ grandi~ quantit\`a:~ evacuare~ la~
    zona.~ Rischio~ di~ esplosione.~ Utilizzare~ i~ mezzi~ estinguenti~ a~
    grande~ distanza.
  }

% 3.4 Consigli di prudenza - Conservazione
\ghsystem_add_statement:nnn {P} { 401 }
  { Conservare~  \l_ghsystem_dots_tl . }
\ghsystem_add_statement:nnn {P} { 402 }
  { Conservare~ in~ luogo~ asciutto. }
\ghsystem_add_statement:nnn {P} { 403 }
  { Conservare~ in~ luogo~ ben~ ventilato. }
\ghsystem_add_statement:nnn {P} { 404 }
  { Conservare~ in~ un~ recipiente~ chiuso. }
\ghsystem_add_statement:nnn {P} { 405 }
  { Conservare~ sotto~ chiave. }
\ghsystem_add_statement:nnn {P} { 406 }
  {
    Conservare~ in~ recipiente~ resistente~ alla~ corrosione\ghsystem_slash:
    \l_ghsystem_dots_tl\ provvisto~ di~ rivestimento~ interno~ resistente.
  }
\ghsystem_add_statement:nnn {P} { 407 }
 { Mantenere~ uno~ spazio~ libero~ tra~ gli~ scaffali\ghsystem_slash: i~ pallet. }
\ghsystem_add_statement:nnn {P} { 410 }
  { Proteggere~ dai~ raggi~ solari. }
\ghsystem_add_statement:nnn {P} { 411 }
  {
    Conservare~ a~ temperature~ non~ superiori~ a~  \exp_args:No \SI {
      \l_ghsystem_celsius_temperature_tl }{ \GHScelsius } .
  }
\ghsystem_add_statement:nnn {P} { 412 }
  { Non~ esporre~ a~ temperature~ superiori~ a~  \SI { 50 } { \GHScelsius } . }
\ghsystem_add_statement:nnn {P} { 413 }
  {
    Conservare~ le~ rinfuse~ di~ peso~ superiore~ a~  \exp_args:No \SI {
      \l_ghsystem_kg_mass_tl }{ \GHSkilogram } ~  a~ temperature~ non~
    superiori~ a ~  \exp_args:No \SI { \l_ghsystem_celsius_temperature_tl } {
      \GHScelsius } .
  }
\ghsystem_add_statement:nnn {P} { 420 }
  { Conservare~ lontano~ da~ altri~ materiali. }
\ghsystem_add_statement:nnn {P} { 422 }
  { Conservare~ sotto~ \l_ghsystem_dots_tl . }
\ghsystem_add_statement:nnn {P} { 402 + 404 }
  { Conservare~ in~ luogo~ asciutto~ e~ in~ recipiente~ chiuso. }
\ghsystem_add_statement:nnn {P} { 403 + 233 }
  { Tenere~ il~ recipiente~ ben~ chiuso~ e~ in~ luogo~ ben~ ventilato. }
\ghsystem_add_statement:nnn {P} { 403 + 235 }
  { Conservare~ in~ luogo~ fresco~ e~ ben~ ventilato. }
\ghsystem_add_statement:nnn {P} { 410 + 403 }
  { Proteggere~ dai~ raggi~ solari.~ Conservare~ in~ luogo~ ben~ ventilato. }
\ghsystem_add_statement:nnn {P} { 410 + 412 }
  {
    Proteggere~ dai~ raggi~ solari.~ Non~ esporre~ a~ temperature~ superiori~
    a~  \SI { 50 } { \GHScelsius } .
  }
\ghsystem_add_statement:nnn {P} { 411 + 235 }
  {
    Conservare~ in~ luogo~ fresco~ a~ temperature~ non~ superiori~ a~
    \exp_args:No \SI { \l_ghsystem_celsius_temperature_tl } { \GHScelsius } .
  }

% 3.5 Consigli di prudenza - Smaltimento
\ghsystem_add_statement:nnn {P} { 501 }
  {
    Smaltire~ il~ prodotto\ghsystem_slash: recipiente~ in~
    \l_ghsystem_dots_tl .
  }

% 4 Codici descrittivi di pericolo (Allegato 6, da pagina 4)
\ghsystem_add_statement:nnn {H} { 350i }
  { Pu\`o~ causare~ il~ cancro~ se~ inalato. }
\ghsystem_add_statement:nnn {H} { 360F }
  { Pu\`o~ nuocere~ alla~ fertilit\`a. }
\ghsystem_add_statement:nnn {H} { 360D }
  { Pu\`o~ nuocere~ al~ feto. }
\ghsystem_add_statement:nnn {H} { 361f }
  { Sospettato~ di~ nuocere~ alla~ fertilit\`a. }
\ghsystem_add_statement:nnn {H} { 361d }
  { Sospettato~ di~ nuocere~ al~ feto. }
\ghsystem_add_statement:nnn {H} { 360FD }
  { Pu\`o~ nuocere~ alla~ fertilit\`a.~ Pu\`o~ nuocere~ al~ feto. }
\ghsystem_add_statement:nnn {H} { 361fd }
  {
    Sospettato~ di~ nuocere~ alla~ fertilit\`a.~ Sospettato~ di~ nuocere~ al~
    feto.
  }
\ghsystem_add_statement:nnn {H} { 360Fd }
  { Pu\`o~ nuocere~ alla~ fertilit\`a.~ Sospettato~ di~ nuocere~ al~ feto. }
\ghsystem_add_statement:nnn {H} { 360Df }
  { Pu\`o~ nuocere~ al~ feto.~ Sospettato~ di~ nuocere~ alla~ fertilit\`a. }

